@@ -69,6 +69,8 @@ class ActionSheet: UIViewController {
 
         collectionView.register(ActionSheetCell.self,
                                 forCellWithReuseIdentifier: ActionSheetCell.identifier)
+        collectionView.register(DoubleActionSheetCell.self,
+                                forCellWithReuseIdentifier: DoubleActionSheetCell.reusableIdentifier)
         collectionView.translatesAutoresizingMaskIntoConstraints = false
         return collectionView
     }()
@@ -186,7 +188,6 @@ class ActionSheet: UIViewController {
         mainStackView.addArrangedSubview(collectionWrapperView)
 
         backgroundView.frame = UIScreen.main.bounds
-        backgroundView.isAccessibilityElement = true
 
         backgroundView.accessibilityLabel = NSLocalizedString("ACTIONSHEET_BACKGROUND_LABEL",
                                                               comment: "")
